@@ -6,12 +6,12 @@ typedef struct {
 	lt_dlhandle mode_handle;
 
 	/* Holds the algorithm's internal key */
-	word8 *akey;
+	byte *akey;
 
-	word8 *abuf; /* holds the mode's internal buffers */
+	byte *abuf; /* holds the mode's internal buffers */
 
 	/* holds the key */
-	word8 *keyword_given;
+	byte *keyword_given;
 
 /* These were included to speed up encryption/decryption proccess, so
  * there is not need for resolving symbols every time.
@@ -27,11 +27,6 @@ typedef CRYPT_STREAM* MCRYPT;
 
 #define MCRYPT_FAILED 0x0
 
-void mcrypt_block_encrypt(MCRYPT td, void *);
-void mcrypt_block_decrypt(MCRYPT td, void *);
-void mcrypt_stream_encrypt(MCRYPT td, void *, int);
-void mcrypt_stream_decrypt(MCRYPT td, void *, int);
-
 int mcrypt_module_close(MCRYPT td);
 
 /* frontends */
@@ -39,7 +34,7 @@ int mcrypt_module_close(MCRYPT td);
 int end_mcrypt( MCRYPT td, void *buf);
 int mcrypt_enc_get_size(MCRYPT td);
 int mcrypt_mode_get_size(MCRYPT td);
-void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e);
+int mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e);
 int mcrypt_enc_get_block_size(MCRYPT td);
 int __mcrypt_get_block_size(MCRYPT td);
 int mcrypt_enc_get_algo_iv_size(MCRYPT td);
