@@ -7,14 +7,12 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish.c,v 1.6 2000/11/08 23:25:36 nmav Exp $ */
+/* $Id: blowfish-compat.c,v 1.4 2001/03/11 20:30:28 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "blowfish.h"
 
-#define WORDS_BIGENDIAN
-
 #ifdef USE_LTDL
 #define _mcrypt_set_key blowfish_compat_LTX__mcrypt_set_key
 #define _mcrypt_encrypt blowfish_compat_LTX__mcrypt_encrypt
@@ -40,11 +38,7 @@ typedef struct {
 #define BF_N         16
 #define KEYBYTES   8
 
-static word32 F(blf_ctx * bc, word32 x)
-{
-	return ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][(x      ) & 0xff];
-
-}
+#define F(bc, x) ( ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][x & 0xff] )
 
 /* x should be a 64 bit integer */
 WIN32DLL_DEFINE
@@ -158,7 +152,7 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 }
 
 
-static short initialize_blowfish(blf_ctx * c, unsigned char key[], short keybytes)
+static short initialize_blowfish(blf_ctx * c, byte key[], short keybytes)
 {
 	short i, j;
 	word32 data, datarl[2];
@@ -574,9 +568,10 @@ static short initialize_blowfish(blf_ctx * c, unsigned char key[], short keybyte
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(blf_ctx * c, char *k, int len)
+int _mcrypt_set_key(blf_ctx * c, char *k, int len)
 {
 	initialize_blowfish(c, k, len);
+	return 0;
 }
 
 WIN32DLL_DEFINE
@@ -595,7 +590,7 @@ int* _mcrypt_get_supported_key_sizes(int *len) {
 WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Blowfish"); return x;}
 
-#define CIPHER "c8c033bc57874d74"
+#define CIPHER "de8e9a3a9cd44280"
 
 WIN32DLL_DEFINE
 int _mcrypt_self_test() {
