@@ -16,7 +16,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: cast-256.c,v 1.4 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: cast-256.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
 
 /* modified for mcrypt */
 
@@ -82,7 +82,7 @@ Mean:          674 cycles =    38.0 mbits/sec
 #define _mcrypt_algorithm_version cast_256_LTX__mcrypt_algorithm_version
 #endif
 
-#define byte(x,n)   ((word8)((x) >> (8 * n)))
+#define byte(x,n)   ((byte)((x) >> (8 * n)))
 
 word32 cast256_sbox[4][256] = { {
 				 0x30fb40d4, 0x9fa0ff0b, 0x6beccd2f,
@@ -357,7 +357,7 @@ word32 cast256_sbox[4][256] = { {
 
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(cast256_key * key, const word32 * in_key,
+int _mcrypt_set_key(cast256_key * key, const word32 * in_key,
 		     const int key_len)
 {
 	word32 i, j, t, u, cm, cr, lk[8], tm[8], tr[8];
@@ -406,6 +406,7 @@ void _mcrypt_set_key(cast256_key * key, const word32 * in_key,
 		key->l_key[i + 7] = lk[1];
 	}
 
+return 0;
 }
 
 /* encrypt a block of text  */
