@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: enigma.c,v 1.4 2001/01/22 22:13:19 nmav Exp $ */
+/* $Id: enigma.c,v 1.5 2001/04/25 09:49:11 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -220,7 +220,7 @@ int _mcrypt_self_test() {
 
 	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL, 0);
 	if (key==NULL) {
-		fprintf (stderr, "Internal error (NULL key)\n"); 
+		printf ("Internal error (NULL key)\n"); 
 		return -1;
 	}
 	_mcrypt_encrypt( key, (void*)ciphertext, blocksize);
