@@ -1,6 +1,6 @@
 /* panama_x.c */
 
-/* $Id: panama.c,v 1.5 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: panama.c,v 1.9 2001/02/01 10:34:51 nmav Exp $ */
 
 /* daemen.j@protonworld.com */
 /**************************************************************************+
@@ -516,7 +516,7 @@ void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state)
 +**************************************************************************/
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
+int _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 			 char *init_vec, int vecsize)
 {
 	char* key;
@@ -526,6 +526,8 @@ void _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 	int i;
 	
 	key=mxcalloc(1, 32);
+	if (key==NULL) return -1;
+	
 	memmove( key, in_key, keysize);
 #else
 	key=in_key;
@@ -535,7 +537,7 @@ void _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 	pan_reset(&pan_key->buffer, &pan_key->state);
 	pan_push((void *) key, keyblocks, &pan_key->buffer,
 		 &pan_key->state);
-	pan_push((void *) init_vec, vecblocks, &pan_key->buffer,
+	if (init_vec!=NULL) pan_push((void *) init_vec, vecblocks, &pan_key->buffer,
 		 &pan_key->state);
 
 	pan_pull(NULL, NULL, 32, &pan_key->buffer, &pan_key->state);
@@ -552,11 +554,12 @@ void _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 	mxfree(key,32);
 #endif
 
+return 0;
 }
 
 WIN32DLL_DEFINE
 void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
-		    word8 * buf,	/* input array                         */
+		    byte * buf,	/* input array                         */
 		    int length)
 {				/* length to be encrypted, in bits     */
 	int i;
@@ -586,32 +589,10 @@ void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
 
 WIN32DLL_DEFINE
 void _mcrypt_decrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
-		    word8 * buf,	/* input array                         */
+		    byte * buf,	/* input array                         */
 		    int length)
 {				/* length to be encrypted, in bits     */
-	int i;
-#ifdef WORDS_BIGENDIAN
-	int j;
-#endif
-
-/* initialize the Panama state machine for a fresh crypting operation */
-	for (i = 0; i < length; i++) {
-
-		if (pan_key->keymat_pointer == 32) {
-			pan_pull(NULL, (void *) &pan_key->keymat, 1,
-				 &pan_key->buffer, &pan_key->state);
-			pan_key->keymat_pointer = 0;
-#ifdef WORDS_BIGENDIAN
-			for (j = 0; j < 8; j++) {
-				    ((word32 *) pan_key->keymat)[j] =
-				    byteswap32(((word32 *) pan_key->keymat)
-					     [j]);
-			}
-#endif
-		}
-		buf[i] ^= pan_key->keymat[pan_key->keymat_pointer];
-		pan_key->keymat_pointer++;
-	}
+   _mcrypt_encrypt( pan_key, buf, length);
 }
 
 /**************************************************************************/
@@ -691,5 +672,5 @@ int _mcrypt_self_test() {
 
 WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version(void) {
-	return 19991202;
+	return 20010201;
 }
