@@ -459,7 +459,7 @@ Mean:          941 cycles =    27.2 mbits/sec
 /* initialise the key schedule from the user supplied key   */
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
+int _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 			     word32 key_len)
 {
 	word32 i, lk, a, b, c, d, e, f, g, h;
@@ -469,7 +469,7 @@ void _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 	key_len *= 8;
 	if (key_len > 256)
 
-		return;
+		return -1;
 
 	i = 0;
 	lk = (key_len + 31) / 32;
@@ -603,7 +603,7 @@ void _mcrypt_set_key(SERPENT_KEY * spkey, const word32* in_key,
 	sb3(a, b, c, d, e, f, g, h);
 	k_get(32, e, f, g, h);
 
-	return;
+	return 0;
 }
 
 /* encrypt a block of text  */
